from _typeshed import Incomplete

from win32comext.axdebug import gateways
from win32comext.axdebug.codecontainer import SourceCodeContainer

debuggingTrace: int

def trace(*args) -> None: ...

class DebugManager:
    scriptEngine: Incomplete
    adb: Incomplete
    rootNode: Incomplete
    debugApplication: Incomplete
    ccProvider: Incomplete
    scriptSiteDebug: Incomplete
    activeScriptDebug: Incomplete
    codeContainers: Incomplete
    def __init__(self, scriptEngine) -> None: ...
    def Close(self) -> None: ...
    def IsAnyHost(self): ...
    def IsSimpleHost(self): ...
    def HandleRuntimeError(self): ...
    def OnEnterScript(self) -> None: ...
    def OnLeaveScript(self) -> None: ...
    def AddScriptBlock(self, codeBlock) -> None: ...

class DebugCodeBlockContainer(SourceCodeContainer):
    codeBlock: Incomplete
    def __init__(self, codeBlock, site) -> None: ...
    def GetName(self, dnt): ...

class EnumDebugCodeContexts(gateways.EnumDebugCodeContexts): ...

class ActiveScriptDebug:
    debugMgr: Incomplete
    scriptSiteDebug: Incomplete
    codeContainers: Incomplete
    def __init__(self, debugMgr, codeContainers) -> None: ...
    def GetScriptTextAttributes(self, code, delim, flags): ...
    def GetScriptletTextAttributes(self, code, delim, flags): ...
    def EnumCodeContextsOfPosition(self, context, charOffset, numChars): ...



import _win32typing

def AfxOleInit(enabled, /) -> None: ...
def CreateInsertDialog() -> _win32typing.PyCOleInsertDialog: ...
def CreateOleClientItem() -> _win32typing.PyCOleClientItem: ...
def CreateOleDocument(
    template: _win32typing.PyCDocTemplate | _win32typing.DocTemplate, fileName: str | None = ..., /
) -> _win32typing.PyCOleDocument: ...
def DaoGetEngine() -> _win32typing.PyIDispatch: ...
def GetIDispatchForWindow(Wnd, /) -> _win32typing.PyIDispatch: ...
def OleGetUserCtrl(): ...
def OleSetUserCtrl(bUserCtrl, /): ...
def SetMessagePendingDelay(delay, /) -> None: ...
def EnableNotRespondingDialog(enabled, /) -> None: ...
def EnableBusyDialog(*args): ...  # incomplete

COleClientItem_activeState: int
COleClientItem_activeUIState: int
COleClientItem_emptyState: int
COleClientItem_loadedState: int
COleClientItem_openState: int
OLE_CHANGED: int
OLE_CHANGED_ASPECT: int
OLE_CHANGED_STATE: int
OLE_CLOSED: int
OLE_RENAMED: int
OLE_SAVED: int



from collections.abc import MutableSequence

from . import gen_py as gen_py

__gen_path__: str
__build_path__: str | None

def SetupEnvironment() -> None: ...
def __PackageSupportBuildPath__(package_path: MutableSequence[str]) -> None: ...



from _typeshed import Incomplete
from collections.abc import Iterable

import _win32typing
import win32api

error = win32api.error
langid: Incomplete

def AddSourceToRegistry(
    appName,
    msgDLL: Incomplete | None = None,
    eventLogType: str = "Application",
    eventLogFlags: Incomplete | None = None,
    categoryDLL: Incomplete | None = None,
    categoryCount: int = 0,
) -> None: ...
def RemoveSourceFromRegistry(appName, eventLogType: str = ...) -> None: ...
def ReportEvent(
    appName: str,
    eventID: int,
    eventCategory: int = ...,
    eventType: int = ...,
    strings: Iterable[str] | None = ...,
    data: bytes | None = ...,
    sid: _win32typing.PySID | None = ...,
) -> None: ...
def FormatMessage(eventLogRecord: _win32typing.PyEventLogRecord, logType: str = ...): ...
def SafeFormatMessage(eventLogRecord, logType: Incomplete | None = ...): ...
def FeedEventLogRecords(feeder, machineName: Incomplete | None = ..., logName: str = ..., readFlags: Incomplete | None = ...): ...



from _typeshed import Incomplete

PERF_DATA_VERSION: int
PERF_DATA_REVISION: int
PERF_NO_INSTANCES: int
PERF_SIZE_DWORD: int
PERF_SIZE_LARGE: int
PERF_SIZE_ZERO: int
PERF_SIZE_VARIABLE_LEN: int
PERF_TYPE_NUMBER: int
PERF_TYPE_COUNTER: int
PERF_TYPE_TEXT: int
PERF_TYPE_ZERO: int
PERF_NUMBER_HEX: int
PERF_NUMBER_DECIMAL: int
PERF_NUMBER_DEC_1000: int
PERF_COUNTER_VALUE: int
PERF_COUNTER_RATE: int
PERF_COUNTER_FRACTION: int
PERF_COUNTER_BASE: int
PERF_COUNTER_ELAPSED: int
PERF_COUNTER_QUEUELEN: int
PERF_COUNTER_HISTOGRAM: int
PERF_TEXT_UNICODE: int
PERF_TEXT_ASCII: int
PERF_TIMER_TICK: int
PERF_TIMER_100NS: int
PERF_OBJECT_TIMER: int
PERF_DELTA_COUNTER: int
PERF_DELTA_BASE: int
PERF_INVERSE_COUNTER: int
PERF_MULTI_COUNTER: int
PERF_DISPLAY_NO_SUFFIX: int
PERF_DISPLAY_PER_SEC: int
PERF_DISPLAY_PERCENT: int
PERF_DISPLAY_SECONDS: int
PERF_DISPLAY_NOSHOW: int
PERF_COUNTER_COUNTER: Incomplete
PERF_COUNTER_TIMER: Incomplete
PERF_COUNTER_QUEUELEN_TYPE: Incomplete
PERF_COUNTER_LARGE_QUEUELEN_TYPE: Incomplete
PERF_COUNTER_BULK_COUNT: Incomplete
PERF_COUNTER_TEXT: Incomplete
PERF_COUNTER_RAWCOUNT: Incomplete
PERF_COUNTER_LARGE_RAWCOUNT: Incomplete
PERF_COUNTER_RAWCOUNT_HEX: Incomplete
PERF_COUNTER_LARGE_RAWCOUNT_HEX: Incomplete
PERF_SAMPLE_FRACTION: Incomplete
PERF_SAMPLE_COUNTER: Incomplete
PERF_COUNTER_NODATA: Incomplete
PERF_COUNTER_TIMER_INV: Incomplete
PERF_SAMPLE_BASE: Incomplete
PERF_AVERAGE_TIMER: Incomplete
PERF_AVERAGE_BASE: Incomplete
PERF_AVERAGE_BULK: Incomplete
PERF_100NSEC_TIMER: Incomplete
PERF_100NSEC_TIMER_INV: Incomplete
PERF_COUNTER_MULTI_TIMER: Incomplete
PERF_COUNTER_MULTI_TIMER_INV: Incomplete
PERF_COUNTER_MULTI_BASE: Incomplete
PERF_100NSEC_MULTI_TIMER: Incomplete
PERF_100NSEC_MULTI_TIMER_INV: Incomplete
PERF_RAW_FRACTION: Incomplete
PERF_RAW_BASE: Incomplete
PERF_ELAPSED_TIME: Incomplete
PERF_COUNTER_HISTOGRAM_TYPE: int
PERF_COUNTER_DELTA: Incomplete
PERF_COUNTER_LARGE_DELTA: Incomplete
PERF_DETAIL_NOVICE: int
PERF_DETAIL_ADVANCED: int
PERF_DETAIL_EXPERT: int
PERF_DETAIL_WIZARD: int
PERF_NO_UNIQUE_ID: int



import _win32typing

OPENSTORE_HOME_LOGON: int
OPENSTORE_OVERRIDE_HOME_MDB: int
OPENSTORE_PUBLIC: int
OPENSTORE_TAKE_OWNERSHIP: int
OPENSTORE_USE_ADMIN_PRIVILEGE: int
IID_IExchangeManageStore: _win32typing.PyIID
IID_IExchangeManageStoreEx: _win32typing.PyIID



from _typeshed import Incomplete

from win32com.server.util import ListEnumeratorGateway
from win32comext.axdebug import gateways

def MakeNiceString(ob): ...

class ProvideExpressionContexts(gateways.ProvideExpressionContexts): ...

class ExpressionContext(gateways.DebugExpressionContext):
    frame: Incomplete
    def __init__(self, frame) -> None: ...
    def ParseLanguageText(self, code, radix, delim, flags): ...
    def GetLanguageInfo(self): ...

class Expression(gateways.DebugExpression):
    callback: Incomplete
    frame: Incomplete
    code: Incomplete
    radix: Incomplete
    delim: Incomplete
    flags: Incomplete
    isComplete: int
    result: Incomplete
    hresult: Incomplete
    def __init__(self, frame, code, radix, delim, flags) -> None: ...
    def Start(self, callback): ...
    def Abort(self) -> None: ...
    def QueryIsComplete(self): ...
    def GetResultAsString(self): ...
    def GetResultAsDebugProperty(self): ...

def MakeEnumDebugProperty(object, dwFieldSpec, nRadix, iid, stackFrame: Incomplete | None = ...): ...
def GetPropertyInfo(
    obname,
    obvalue,
    dwFieldSpec,
    nRadix,
    hresult: int = ...,
    dictionary: Incomplete | None = ...,
    stackFrame: Incomplete | None = ...,
): ...

class EnumDebugPropertyInfo(ListEnumeratorGateway):
    def GetCount(self): ...

class DebugProperty:
    name: Incomplete
    value: Incomplete
    parent: Incomplete
    hresult: Incomplete
    dictionary: Incomplete
    stackFrame: Incomplete
    def __init__(
        self,
        name,
        value,
        parent: Incomplete | None = ...,
        hresult: int = ...,
        dictionary: Incomplete | None = ...,
        stackFrame: Incomplete | None = ...,
    ) -> None: ...
    def GetPropertyInfo(self, dwFieldSpec, nRadix): ...
    def GetExtendedInfo(self) -> None: ...
    def SetValueAsString(self, value, radix) -> None: ...
    def EnumMembers(self, dwFieldSpec, nRadix, iid): ...
    def GetParent(self) -> None: ...



from typing_extensions import TypeAlias

import _win32typing
from win32.lib.pywintypes import com_error

error: TypeAlias = com_error  # noqa: Y042

def PSGetItemPropertyHandler(
    Item: _win32typing.PyIShellItem, riid: _win32typing.PyIID, ReadWrite: int, /
) -> _win32typing.PyIPropertyStore: ...
def PSGetPropertyDescription(
    Key: _win32typing.PyPROPERTYKEY, riid: _win32typing.PyIID, /
) -> _win32typing.PyIPropertyDescription: ...
def PSGetPropertySystem(riid: _win32typing.PyIID, /) -> _win32typing.PyIPropertySystem: ...
def PSGetNameFromPropertyKey(Key: _win32typing.PyPROPERTYKEY, /) -> str: ...
def PSGetPropertyKeyFromName(Name, /) -> _win32typing.PyPROPERTYKEY: ...
def PSRegisterPropertySchema(filename, /) -> None: ...
def PSUnregisterPropertySchema(filename, /) -> None: ...
def SHGetPropertyStoreFromParsingName(
    Path: str, BindCtx: _win32typing.PyIBindCtx | None = ..., Flags: int = ..., riid: _win32typing.PyIID | str = ..., /
) -> _win32typing.PyIPropertyStore: ...
def StgSerializePropVariant(propvar: _win32typing.PyPROPVARIANT, /): ...
def StgDeserializePropVariant(prop, /) -> _win32typing.PyPROPVARIANT: ...
def PSCreateMemoryPropertyStore(riid: _win32typing.PyIID, /) -> _win32typing.PyIPropertyStore: ...
def PSCreatePropertyStoreFromPropertySetStorage(
    pss: _win32typing.PyIPropertySetStorage, Mode, riid: _win32typing.PyIID, /
) -> _win32typing.PyIPropertyStore: ...
def PSLookupPropertyHandlerCLSID(FilePath, /) -> _win32typing.PyIID: ...
def SHGetPropertyStoreForWindow(hwnd: int, riid: _win32typing.PyIID, /) -> _win32typing.PyIPropertyStore: ...
def PSGetPropertyFromPropertyStorage(ps, key: _win32typing.PyPROPERTYKEY, /) -> _win32typing.PyPROPVARIANT: ...
def PSGetNamedPropertyFromPropertyStorage(ps, name, /) -> _win32typing.PyPROPVARIANT: ...
def PSCreateSimplePropertyChange(
    flags, key: _win32typing.PyPROPERTYKEY, val: _win32typing.PyPROPVARIANT, riid: _win32typing.PyIID, /
) -> _win32typing.PyIPropertyChange: ...
def PSCreatePropertyChangeArray() -> _win32typing.PyIPropertyChangeArray: ...
def SHSetDefaultProperties(
    hwnd: int,
    Item: _win32typing.PyIShellItem,
    FileOpFlags: int = ...,
    Sink: _win32typing.PyGFileOperationProgressSink | None = ...,
    /,
) -> None: ...

IID_IInitializeWithFile: _win32typing.PyIID
IID_IInitializeWithStream: _win32typing.PyIID
IID_INamedPropertyStore: _win32typing.PyIID
IID_IObjectWithPropertyKey: _win32typing.PyIID
IID_IPersistSerializedPropStorage: _win32typing.PyIID
IID_IPropertyChange: _win32typing.PyIID
IID_IPropertyChangeArray: _win32typing.PyIID
IID_IPropertyDescription: _win32typing.PyIID
IID_IPropertyDescriptionAliasInfo: _win32typing.PyIID
IID_IPropertyDescriptionList: _win32typing.PyIID
IID_IPropertyDescriptionSearchInfo: _win32typing.PyIID
IID_IPropertyEnumType: _win32typing.PyIID
IID_IPropertyEnumTypeList: _win32typing.PyIID
IID_IPropertyStore: _win32typing.PyIID
IID_IPropertyStoreCache: _win32typing.PyIID
IID_IPropertyStoreCapabilities: _win32typing.PyIID
IID_IPropertySystem: _win32typing.PyIID
PROPVARIANTType = _win32typing.PyPROPVARIANT



RASEAPF_Logon: int
RASEAPF_NonInteractive: int
RASEAPF_Preview: int

def GetEapUserIdentity(*args): ...  # incomplete

RASCS_AllDevicesConnected: int
RASCS_AuthAck: int
RASCS_AuthCallback: int
RASCS_AuthChangePassword: int
RASCS_AuthLinkSpeed: int
RASCS_AuthNotify: int
RASCS_AuthProject: int
RASCS_AuthRetry: int
RASCS_Authenticate: int
RASCS_Authenticated: int
RASCS_CallbackComplete: int
RASCS_CallbackSetByCaller: int
RASCS_ConnectDevice: int
RASCS_Connected: int
RASCS_DeviceConnected: int
RASCS_Disconnected: int
RASCS_Interactive: int
RASCS_LogonNetwork: int
RASCS_OpenPort: int
RASCS_PasswordExpired: int
RASCS_PortOpened: int
RASCS_PrepareForCallback: int
RASCS_Projected: int
RASCS_ReAuthenticate: int
RASCS_RetryAuthentication: int
RASCS_StartAuthentication: int
RASCS_WaitForCallback: int
RASCS_WaitForModemReset: int



from logging import Logger
from typing_extensions import TypeAlias

from win32com.server.policy import BasicWrapPolicy

class DispatcherBase:
    policy: BasicWrapPolicy
    logger: Logger
    def __init__(self, policyClass, object) -> None: ...

class DispatcherTrace(DispatcherBase): ...

class DispatcherWin32trace(DispatcherTrace):
    def __init__(self, policyClass, object) -> None: ...

class DispatcherOutputDebugString(DispatcherTrace): ...

DefaultDebugDispatcher: TypeAlias = DispatcherTrace



from typing_extensions import TypeAlias

_SixIntTuple: TypeAlias = tuple[int, int, int, int, int, int]

DELETE: int
READ_CONTROL: int
WRITE_DAC: int
WRITE_OWNER: int
SYNCHRONIZE: int
STANDARD_RIGHTS_REQUIRED: int
STANDARD_RIGHTS_READ: int
STANDARD_RIGHTS_WRITE: int
STANDARD_RIGHTS_EXECUTE: int
STANDARD_RIGHTS_ALL: int
SPECIFIC_RIGHTS_ALL: int
ACCESS_SYSTEM_SECURITY: int
MAXIMUM_ALLOWED: int
GENERIC_READ: int
GENERIC_WRITE: int
GENERIC_EXECUTE: int
GENERIC_ALL: int
FILE_READ_DATA: int
FILE_WRITE_DATA: int
FILE_ADD_FILE: int
FILE_APPEND_DATA: int
FILE_ADD_SUBDIRECTORY: int
FILE_CREATE_PIPE_INSTANCE: int
FILE_READ_EA: int
FILE_WRITE_EA: int
FILE_EXECUTE: int
FILE_TRAVERSE: int
FILE_DELETE_CHILD: int
FILE_READ_ATTRIBUTES: int
FILE_WRITE_ATTRIBUTES: int
FILE_ALL_ACCESS: int
FILE_GENERIC_READ: int
FILE_GENERIC_WRITE: int
FILE_GENERIC_EXECUTE: int
SECURITY_NULL_SID_AUTHORITY: _SixIntTuple
SECURITY_WORLD_SID_AUTHORITY: _SixIntTuple
SECURITY_LOCAL_SID_AUTHORITY: _SixIntTuple
SECURITY_CREATOR_SID_AUTHORITY: _SixIntTuple
SECURITY_NON_UNIQUE_AUTHORITY: _SixIntTuple
SECURITY_RESOURCE_MANAGER_AUTHORITY: _SixIntTuple
SECURITY_NULL_RID: int
SECURITY_WORLD_RID: int
SECURITY_LOCAL_RID: int
SECURITY_CREATOR_OWNER_RID: int
SECURITY_CREATOR_GROUP_RID: int
SECURITY_CREATOR_OWNER_SERVER_RID: int
SECURITY_CREATOR_GROUP_SERVER_RID: int
SECURITY_CREATOR_OWNER_RIGHTS_RID: int
SECURITY_NT_AUTHORITY: _SixIntTuple
SECURITY_DIALUP_RID: int
SECURITY_NETWORK_RID: int
SECURITY_BATCH_RID: int
SECURITY_INTERACTIVE_RID: int
SECURITY_SERVICE_RID: int
SECURITY_ANONYMOUS_LOGON_RID: int
SECURITY_PROXY_RID: int
SECURITY_SERVER_LOGON_RID: int
SECURITY_LOGON_IDS_RID: int
SECURITY_LOGON_IDS_RID_COUNT: int
SECURITY_LOCAL_SYSTEM_RID: int
SECURITY_NT_NON_UNIQUE: int
SECURITY_BUILTIN_DOMAIN_RID: int
DOMAIN_USER_RID_ADMIN: int
DOMAIN_USER_RID_GUEST: int
DOMAIN_USER_RID_KRBTGT: int
DOMAIN_USER_RID_MAX: int
DOMAIN_GROUP_RID_ADMINS: int
DOMAIN_GROUP_RID_USERS: int
DOMAIN_GROUP_RID_GUESTS: int
DOMAIN_GROUP_RID_COMPUTERS: int
DOMAIN_GROUP_RID_CONTROLLERS: int
DOMAIN_GROUP_RID_CERT_ADMINS: int
DOMAIN_GROUP_RID_SCHEMA_ADMINS: int
DOMAIN_GROUP_RID_ENTERPRISE_ADMINS: int
DOMAIN_GROUP_RID_POLICY_ADMINS: int
DOMAIN_GROUP_RID_READONLY_CONTROLLERS: int
DOMAIN_ALIAS_RID_ADMINS: int
DOMAIN_ALIAS_RID_USERS: int
DOMAIN_ALIAS_RID_GUESTS: int
DOMAIN_ALIAS_RID_POWER_USERS: int
DOMAIN_ALIAS_RID_ACCOUNT_OPS: int
DOMAIN_ALIAS_RID_SYSTEM_OPS: int
DOMAIN_ALIAS_RID_PRINT_OPS: int
DOMAIN_ALIAS_RID_BACKUP_OPS: int
DOMAIN_ALIAS_RID_REPLICATOR: int
DOMAIN_ALIAS_RID_RAS_SERVERS: int
DOMAIN_ALIAS_RID_PREW2KCOMPACCESS: int
DOMAIN_ALIAS_RID_REMOTE_DESKTOP_USERS: int
DOMAIN_ALIAS_RID_NETWORK_CONFIGURATION_OPS: int
DOMAIN_ALIAS_RID_INCOMING_FOREST_TRUST_BUILDERS: int
DOMAIN_ALIAS_RID_MONITORING_USERS: int
DOMAIN_ALIAS_RID_LOGGING_USERS: int
DOMAIN_ALIAS_RID_AUTHORIZATIONACCESS: int
DOMAIN_ALIAS_RID_TS_LICENSE_SERVERS: int
DOMAIN_ALIAS_RID_DCOM_USERS: int
DOMAIN_ALIAS_RID_IUSERS: int
DOMAIN_ALIAS_RID_CRYPTO_OPERATORS: int
DOMAIN_ALIAS_RID_CACHEABLE_PRINCIPALS_GROUP: int
DOMAIN_ALIAS_RID_NON_CACHEABLE_PRINCIPALS_GROUP: int
DOMAIN_ALIAS_RID_EVENT_LOG_READERS_GROUP: int
SECURITY_MANDATORY_LABEL_AUTHORITY: _SixIntTuple
SECURITY_MANDATORY_UNTRUSTED_RID: int
SECURITY_MANDATORY_LOW_RID: int
SECURITY_MANDATORY_MEDIUM_RID: int
SECURITY_MANDATORY_HIGH_RID: int
SECURITY_MANDATORY_SYSTEM_RID: int
SECURITY_MANDATORY_PROTECTED_PROCESS_RID: int
SECURITY_MANDATORY_MAXIMUM_USER_RID: int
SYSTEM_LUID: tuple[int, int]
ANONYMOUS_LOGON_LUID: tuple[int, int]
LOCALSERVICE_LUID: tuple[int, int]
NETWORKSERVICE_LUID: tuple[int, int]
IUSER_LUID: tuple[int, int]
SE_GROUP_MANDATORY: int
SE_GROUP_ENABLED_BY_DEFAULT: int
SE_GROUP_ENABLED: int
SE_GROUP_OWNER: int
SE_GROUP_USE_FOR_DENY_ONLY: int
SE_GROUP_INTEGRITY: int
SE_GROUP_INTEGRITY_ENABLED: int
SE_GROUP_RESOURCE: int
SE_GROUP_LOGON_ID: int
ACCESS_MIN_MS_ACE_TYPE: int
ACCESS_ALLOWED_ACE_TYPE: int
ACCESS_DENIED_ACE_TYPE: int
SYSTEM_AUDIT_ACE_TYPE: int
SYSTEM_ALARM_ACE_TYPE: int
ACCESS_MAX_MS_V2_ACE_TYPE: int
ACCESS_ALLOWED_COMPOUND_ACE_TYPE: int
ACCESS_MAX_MS_V3_ACE_TYPE: int
ACCESS_MIN_MS_OBJECT_ACE_TYPE: int
ACCESS_ALLOWED_OBJECT_ACE_TYPE: int
ACCESS_DENIED_OBJECT_ACE_TYPE: int
SYSTEM_AUDIT_OBJECT_ACE_TYPE: int
SYSTEM_ALARM_OBJECT_ACE_TYPE: int
ACCESS_MAX_MS_OBJECT_ACE_TYPE: int
ACCESS_MAX_MS_V4_ACE_TYPE: int
ACCESS_MAX_MS_ACE_TYPE: int
ACCESS_ALLOWED_CALLBACK_ACE_TYPE: int
ACCESS_DENIED_CALLBACK_ACE_TYPE: int
ACCESS_ALLOWED_CALLBACK_OBJECT_ACE_TYPE: int
ACCESS_DENIED_CALLBACK_OBJECT_ACE_TYPE: int
SYSTEM_AUDIT_CALLBACK_ACE_TYPE: int
SYSTEM_ALARM_CALLBACK_ACE_TYPE: int
SYSTEM_AUDIT_CALLBACK_OBJECT_ACE_TYPE: int
SYSTEM_ALARM_CALLBACK_OBJECT_ACE_TYPE: int
SYSTEM_MANDATORY_LABEL_ACE_TYPE: int
ACCESS_MAX_MS_V5_ACE_TYPE: int
OBJECT_INHERIT_ACE: int
CONTAINER_INHERIT_ACE: int
NO_PROPAGATE_INHERIT_ACE: int
INHERIT_ONLY_ACE: int
VALID_INHERIT_FLAGS: int
SUCCESSFUL_ACCESS_ACE_FLAG: int
FAILED_ACCESS_ACE_FLAG: int
SE_OWNER_DEFAULTED: int
SE_GROUP_DEFAULTED: int
SE_DACL_PRESENT: int
SE_DACL_DEFAULTED: int
SE_SACL_PRESENT: int
SE_SACL_DEFAULTED: int
SE_SELF_RELATIVE: int
SE_PRIVILEGE_ENABLED_BY_DEFAULT: int
SE_PRIVILEGE_ENABLED: int
SE_PRIVILEGE_USED_FOR_ACCESS: int
PRIVILEGE_SET_ALL_NECESSARY: int
SE_CREATE_TOKEN_NAME: str
SE_ASSIGNPRIMARYTOKEN_NAME: str
SE_LOCK_MEMORY_NAME: str
SE_INCREASE_QUOTA_NAME: str
SE_UNSOLICITED_INPUT_NAME: str
SE_MACHINE_ACCOUNT_NAME: str
SE_TCB_NAME: str
SE_SECURITY_NAME: str
SE_TAKE_OWNERSHIP_NAME: str
SE_LOAD_DRIVER_NAME: str
SE_SYSTEM_PROFILE_NAME: str
SE_SYSTEMTIME_NAME: str
SE_PROF_SINGLE_PROCESS_NAME: str
SE_INC_BASE_PRIORITY_NAME: str
SE_CREATE_PAGEFILE_NAME: str
SE_CREATE_PERMANENT_NAME: str
SE_BACKUP_NAME: str
SE_RESTORE_NAME: str
SE_SHUTDOWN_NAME: str
SE_DEBUG_NAME: str
SE_AUDIT_NAME: str
SE_SYSTEM_ENVIRONMENT_NAME: str
SE_CHANGE_NOTIFY_NAME: str
SE_REMOTE_SHUTDOWN_NAME: str
SecurityAnonymous: int
SecurityIdentification: int
SecurityImpersonation: int
SecurityDelegation: int
SECURITY_MAX_IMPERSONATION_LEVEL: int
DEFAULT_IMPERSONATION_LEVEL: int
TOKEN_ASSIGN_PRIMARY: int
TOKEN_DUPLICATE: int
TOKEN_IMPERSONATE: int
TOKEN_QUERY: int
TOKEN_QUERY_SOURCE: int
TOKEN_ADJUST_PRIVILEGES: int
TOKEN_ADJUST_GROUPS: int
TOKEN_ADJUST_DEFAULT: int
TOKEN_ALL_ACCESS: int
TOKEN_READ: int
TOKEN_WRITE: int
TOKEN_EXECUTE: int
SidTypeUser: int
SidTypeGroup: int
SidTypeDomain: int
SidTypeAlias: int
SidTypeWellKnownGroup: int
SidTypeDeletedAccount: int
SidTypeInvalid: int
SidTypeUnknown: int
SidTypeComputer: int
SidTypeLabel: int
TokenPrimary: int
TokenImpersonation: int
TokenUser: int
TokenGroups: int
TokenPrivileges: int
TokenOwner: int
TokenPrimaryGroup: int
TokenDefaultDacl: int
TokenSource: int
TokenType: int
TokenImpersonationLevel: int
TokenStatistics: int
TokenRestrictedSids: int
TokenSessionId: int
TokenGroupsAndPrivileges: int
TokenSessionReference: int
TokenSandBoxInert: int
TokenAuditPolicy: int
TokenOrigin: int
TokenElevationType: int
TokenLinkedToken: int
TokenElevation: int
TokenHasRestrictions: int
TokenAccessInformation: int
TokenVirtualizationAllowed: int
TokenVirtualizationEnabled: int
TokenIntegrityLevel: int
TokenUIAccess: int
TokenMandatoryPolicy: int
TokenLogonSid: int
DS_BEHAVIOR_WIN2000: int
DS_BEHAVIOR_WIN2003_WITH_MIXED_DOMAINS: int
DS_BEHAVIOR_WIN2003: int
DS_SYNCED_EVENT_NAME: str
ACTRL_DS_OPEN: int
ACTRL_DS_CREATE_CHILD: int
ACTRL_DS_DELETE_CHILD: int
ACTRL_DS_SELF: int
ACTRL_DS_READ_PROP: int
ACTRL_DS_WRITE_PROP: int
ACTRL_DS_DELETE_TREE: int
ACTRL_DS_CONTROL_ACCESS: int
NTDSAPI_BIND_ALLOW_DELEGATION: int
DS_REPSYNC_ASYNCHRONOUS_OPERATION: int
DS_REPSYNC_WRITEABLE: int
DS_REPSYNC_PERIODIC: int
DS_REPSYNC_INTERSITE_MESSAGING: int
DS_REPSYNC_ALL_SOURCES: int
DS_REPSYNC_FULL: int
DS_REPSYNC_URGENT: int
DS_REPSYNC_NO_DISCARD: int
DS_REPSYNC_FORCE: int
DS_REPSYNC_ADD_REFERENCE: int
DS_REPSYNC_NEVER_COMPLETED: int
DS_REPSYNC_TWO_WAY: int
DS_REPSYNC_NEVER_NOTIFY: int
DS_REPSYNC_INITIAL: int
DS_REPSYNC_USE_COMPRESSION: int
DS_REPSYNC_ABANDONED: int
DS_REPSYNC_INITIAL_IN_PROGRESS: int
DS_REPSYNC_PARTIAL_ATTRIBUTE_SET: int
DS_REPSYNC_REQUEUE: int
DS_REPSYNC_NOTIFICATION: int
DS_REPSYNC_ASYNCHRONOUS_REPLICA: int
DS_REPSYNC_CRITICAL: int
DS_REPSYNC_FULL_IN_PROGRESS: int
DS_REPSYNC_PREEMPTED: int
DS_REPADD_ASYNCHRONOUS_OPERATION: int
DS_REPADD_WRITEABLE: int
DS_REPADD_INITIAL: int
DS_REPADD_PERIODIC: int
DS_REPADD_INTERSITE_MESSAGING: int
DS_REPADD_ASYNCHRONOUS_REPLICA: int
DS_REPADD_DISABLE_NOTIFICATION: int
DS_REPADD_DISABLE_PERIODIC: int
DS_REPADD_USE_COMPRESSION: int
DS_REPADD_NEVER_NOTIFY: int
DS_REPADD_TWO_WAY: int
DS_REPADD_CRITICAL: int
DS_REPDEL_ASYNCHRONOUS_OPERATION: int
DS_REPDEL_WRITEABLE: int
DS_REPDEL_INTERSITE_MESSAGING: int
DS_REPDEL_IGNORE_ERRORS: int
DS_REPDEL_LOCAL_ONLY: int
DS_REPDEL_NO_SOURCE: int
DS_REPDEL_REF_OK: int
DS_REPMOD_ASYNCHRONOUS_OPERATION: int
DS_REPMOD_WRITEABLE: int
DS_REPMOD_UPDATE_FLAGS: int
DS_REPMOD_UPDATE_ADDRESS: int
DS_REPMOD_UPDATE_SCHEDULE: int
DS_REPMOD_UPDATE_RESULT: int
DS_REPMOD_UPDATE_TRANSPORT: int
DS_REPUPD_ASYNCHRONOUS_OPERATION: int
DS_REPUPD_WRITEABLE: int
DS_REPUPD_ADD_REFERENCE: int
DS_REPUPD_DELETE_REFERENCE: int
DS_INSTANCETYPE_IS_NC_HEAD: int
DS_INSTANCETYPE_NC_IS_WRITEABLE: int
DS_INSTANCETYPE_NC_COMING: int
DS_INSTANCETYPE_NC_GOING: int
NTDSDSA_OPT_IS_GC: int
NTDSDSA_OPT_DISABLE_INBOUND_REPL: int
NTDSDSA_OPT_DISABLE_OUTBOUND_REPL: int
NTDSDSA_OPT_DISABLE_NTDSCONN_XLATE: int
NTDSCONN_OPT_IS_GENERATED: int
NTDSCONN_OPT_TWOWAY_SYNC: int
NTDSCONN_OPT_OVERRIDE_NOTIFY_DEFAULT: int
NTDSCONN_OPT_USE_NOTIFY: int
NTDSCONN_OPT_DISABLE_INTERSITE_COMPRESSION: int
NTDSCONN_OPT_USER_OWNED_SCHEDULE: int
NTDSCONN_KCC_NO_REASON: int
NTDSCONN_KCC_GC_TOPOLOGY: int
NTDSCONN_KCC_RING_TOPOLOGY: int
NTDSCONN_KCC_MINIMIZE_HOPS_TOPOLOGY: int
NTDSCONN_KCC_STALE_SERVERS_TOPOLOGY: int
NTDSCONN_KCC_OSCILLATING_CONNECTION_TOPOLOGY: int
NTDSCONN_KCC_INTERSITE_GC_TOPOLOGY: int
NTDSCONN_KCC_INTERSITE_TOPOLOGY: int
NTDSCONN_KCC_SERVER_FAILOVER_TOPOLOGY: int
NTDSCONN_KCC_SITE_FAILOVER_TOPOLOGY: int
NTDSCONN_KCC_REDUNDANT_SERVER_TOPOLOGY: int
FRSCONN_PRIORITY_MASK: int
FRSCONN_MAX_PRIORITY: int
NTDSCONN_OPT_IGNORE_SCHEDULE_MASK: int
NTDSSETTINGS_OPT_IS_AUTO_TOPOLOGY_DISABLED: int
NTDSSETTINGS_OPT_IS_TOPL_CLEANUP_DISABLED: int
NTDSSETTINGS_OPT_IS_TOPL_MIN_HOPS_DISABLED: int
NTDSSETTINGS_OPT_IS_TOPL_DETECT_STALE_DISABLED: int
NTDSSETTINGS_OPT_IS_INTER_SITE_AUTO_TOPOLOGY_DISABLED: int
NTDSSETTINGS_OPT_IS_GROUP_CACHING_ENABLED: int
NTDSSETTINGS_OPT_FORCE_KCC_WHISTLER_BEHAVIOR: int
NTDSSETTINGS_OPT_FORCE_KCC_W2K_ELECTION: int
NTDSSETTINGS_OPT_IS_RAND_BH_SELECTION_DISABLED: int
NTDSSETTINGS_OPT_IS_SCHEDULE_HASHING_ENABLED: int
NTDSSETTINGS_OPT_IS_REDUNDANT_SERVER_TOPOLOGY_ENABLED: int
NTDSSETTINGS_DEFAULT_SERVER_REDUNDANCY: int
NTDSTRANSPORT_OPT_IGNORE_SCHEDULES: int
NTDSTRANSPORT_OPT_BRIDGES_REQUIRED: int
NTDSSITECONN_OPT_USE_NOTIFY: int
NTDSSITECONN_OPT_TWOWAY_SYNC: int
NTDSSITECONN_OPT_DISABLE_COMPRESSION: int
NTDSSITELINK_OPT_USE_NOTIFY: int
NTDSSITELINK_OPT_TWOWAY_SYNC: int
NTDSSITELINK_OPT_DISABLE_COMPRESSION: int
GUID_USERS_CONTAINER_A: str
GUID_COMPUTRS_CONTAINER_A: str
GUID_SYSTEMS_CONTAINER_A: str
GUID_DOMAIN_CONTROLLERS_CONTAINER_A: str
GUID_INFRASTRUCTURE_CONTAINER_A: str
GUID_DELETED_OBJECTS_CONTAINER_A: str
GUID_LOSTANDFOUND_CONTAINER_A: str
GUID_FOREIGNSECURITYPRINCIPALS_CONTAINER_A: str
GUID_PROGRAM_DATA_CONTAINER_A: str
GUID_MICROSOFT_PROGRAM_DATA_CONTAINER_A: str
GUID_NTDS_QUOTAS_CONTAINER_A: str
GUID_USERS_CONTAINER_BYTE: str
GUID_COMPUTRS_CONTAINER_BYTE: str
GUID_SYSTEMS_CONTAINER_BYTE: str
GUID_DOMAIN_CONTROLLERS_CONTAINER_BYTE: str
GUID_INFRASTRUCTURE_CONTAINER_BYTE: str
GUID_DELETED_OBJECTS_CONTAINER_BYTE: str
GUID_LOSTANDFOUND_CONTAINER_BYTE: str
GUID_FOREIGNSECURITYPRINCIPALS_CONTAINER_BYTE: str
GUID_PROGRAM_DATA_CONTAINER_BYTE: str
GUID_MICROSOFT_PROGRAM_DATA_CONTAINER_BYTE: str
GUID_NTDS_QUOTAS_CONTAINER_BYTE: str
DS_REPSYNCALL_NO_OPTIONS: int
DS_REPSYNCALL_ABORT_IF_SERVER_UNAVAILABLE: int
DS_REPSYNCALL_SYNC_ADJACENT_SERVERS_ONLY: int
DS_REPSYNCALL_ID_SERVERS_BY_DN: int
DS_REPSYNCALL_DO_NOT_SYNC: int
DS_REPSYNCALL_SKIP_INITIAL_CHECK: int
DS_REPSYNCALL_PUSH_CHANGES_OUTWARD: int
DS_REPSYNCALL_CROSS_SITE_BOUNDARIES: int
DS_ROLE_SCHEMA_OWNER: int
DS_ROLE_DOMAIN_OWNER: int
DS_ROLE_PDC_OWNER: int
DS_ROLE_RID_OWNER: int
DS_ROLE_INFRASTRUCTURE_OWNER: int
DS_SCHEMA_GUID_NOT_FOUND: int
DS_SCHEMA_GUID_ATTR: int
DS_SCHEMA_GUID_ATTR_SET: int
DS_SCHEMA_GUID_CLASS: int
DS_SCHEMA_GUID_CONTROL_RIGHT: int
DS_KCC_FLAG_ASYNC_OP: int
DS_KCC_FLAG_DAMPED: int
DS_EXIST_ADVISORY_MODE: int
DS_REPL_INFO_FLAG_IMPROVE_LINKED_ATTRS: int
DS_REPL_NBR_WRITEABLE: int
DS_REPL_NBR_SYNC_ON_STARTUP: int
DS_REPL_NBR_DO_SCHEDULED_SYNCS: int
DS_REPL_NBR_USE_ASYNC_INTERSITE_TRANSPORT: int
DS_REPL_NBR_TWO_WAY_SYNC: int
DS_REPL_NBR_RETURN_OBJECT_PARENTS: int
DS_REPL_NBR_FULL_SYNC_IN_PROGRESS: int
DS_REPL_NBR_FULL_SYNC_NEXT_PACKET: int
DS_REPL_NBR_NEVER_SYNCED: int
DS_REPL_NBR_PREEMPTED: int
DS_REPL_NBR_IGNORE_CHANGE_NOTIFICATIONS: int
DS_REPL_NBR_DISABLE_SCHEDULED_SYNC: int
DS_REPL_NBR_COMPRESS_CHANGES: int
DS_REPL_NBR_NO_CHANGE_NOTIFICATIONS: int
DS_REPL_NBR_PARTIAL_ATTRIBUTE_SET: int
DS_REPL_NBR_MODIFIABLE_MASK: int
DS_UNKNOWN_NAME: int
DS_FQDN_1779_NAME: int
DS_NT4_ACCOUNT_NAME: int
DS_DISPLAY_NAME: int
DS_UNIQUE_ID_NAME: int
DS_CANONICAL_NAME: int
DS_USER_PRINCIPAL_NAME: int
DS_CANONICAL_NAME_EX: int
DS_SERVICE_PRINCIPAL_NAME: int
DS_SID_OR_SID_HISTORY_NAME: int
DS_DNS_DOMAIN_NAME: int
DS_DOMAIN_SIMPLE_NAME: int
DS_ENTERPRISE_SIMPLE_NAME: int
DS_NAME_NO_FLAGS: int
DS_NAME_FLAG_SYNTACTICAL_ONLY: int
DS_NAME_FLAG_EVAL_AT_DC: int
DS_NAME_FLAG_GCVERIFY: int
DS_NAME_FLAG_TRUST_REFERRAL: int
DS_NAME_NO_ERROR: int
DS_NAME_ERROR_RESOLVING: int
DS_NAME_ERROR_NOT_FOUND: int
DS_NAME_ERROR_NOT_UNIQUE: int
DS_NAME_ERROR_NO_MAPPING: int
DS_NAME_ERROR_DOMAIN_ONLY: int
DS_NAME_ERROR_NO_SYNTACTICAL_MAPPING: int
DS_NAME_ERROR_TRUST_REFERRAL: int
DS_SPN_DNS_HOST: int
DS_SPN_DN_HOST: int
DS_SPN_NB_HOST: int
DS_SPN_DOMAIN: int
DS_SPN_NB_DOMAIN: int
DS_SPN_SERVICE: int
DS_SPN_ADD_SPN_OP: int
DS_SPN_REPLACE_SPN_OP: int
DS_SPN_DELETE_SPN_OP: int
DS_FORCE_REDISCOVERY: int
DS_DIRECTORY_SERVICE_REQUIRED: int
DS_DIRECTORY_SERVICE_PREFERRED: int
DS_GC_SERVER_REQUIRED: int
DS_PDC_REQUIRED: int
DS_BACKGROUND_ONLY: int
DS_IP_REQUIRED: int
DS_KDC_REQUIRED: int
DS_TIMESERV_REQUIRED: int
DS_WRITABLE_REQUIRED: int
DS_GOOD_TIMESERV_PREFERRED: int
DS_AVOID_SELF: int
DS_ONLY_LDAP_NEEDED: int
DS_IS_FLAT_NAME: int
DS_IS_DNS_NAME: int
DS_RETURN_DNS_NAME: int
DS_RETURN_FLAT_NAME: int
DSGETDC_VALID_FLAGS: int
DS_INET_ADDRESS: int
DS_NETBIOS_ADDRESS: int
DS_PDC_FLAG: int
DS_GC_FLAG: int
DS_LDAP_FLAG: int
DS_DS_FLAG: int
DS_KDC_FLAG: int
DS_TIMESERV_FLAG: int
DS_CLOSEST_FLAG: int
DS_WRITABLE_FLAG: int
DS_GOOD_TIMESERV_FLAG: int
DS_NDNC_FLAG: int
DS_PING_FLAGS: int
DS_DNS_CONTROLLER_FLAG: int
DS_DNS_DOMAIN_FLAG: int
DS_DNS_FOREST_FLAG: int
DS_DOMAIN_IN_FOREST: int
DS_DOMAIN_DIRECT_OUTBOUND: int
DS_DOMAIN_TREE_ROOT: int
DS_DOMAIN_PRIMARY: int
DS_DOMAIN_NATIVE_MODE: int
DS_DOMAIN_DIRECT_INBOUND: int
DS_DOMAIN_VALID_FLAGS: int
DS_GFTI_UPDATE_TDO: int
DS_GFTI_VALID_FLAGS: int
DS_ONLY_DO_SITE_NAME: int
DS_NOTIFY_AFTER_SITE_RECORDS: int
DS_OPEN_VALID_OPTION_FLAGS: int
DS_OPEN_VALID_FLAGS: int
SI_EDIT_PERMS: int
SI_EDIT_OWNER: int
SI_EDIT_AUDITS: int
SI_CONTAINER: int
SI_READONLY: int
SI_ADVANCED: int
SI_RESET: int
SI_OWNER_READONLY: int
SI_EDIT_PROPERTIES: int
SI_OWNER_RECURSE: int
SI_NO_ACL_PROTECT: int
SI_NO_TREE_APPLY: int
SI_PAGE_TITLE: int
SI_SERVER_IS_DC: int
SI_RESET_DACL_TREE: int
SI_RESET_SACL_TREE: int
SI_OBJECT_GUID: int
SI_EDIT_EFFECTIVE: int
SI_RESET_DACL: int
SI_RESET_SACL: int
SI_RESET_OWNER: int
SI_NO_ADDITIONAL_PERMISSION: int
SI_MAY_WRITE: int
SI_EDIT_ALL: int
SI_AUDITS_ELEVATION_REQUIRED: int
SI_VIEW_ONLY: int
SI_OWNER_ELEVATION_REQUIRED: int
SI_PERMS_ELEVATION_REQUIRED: int
SI_ACCESS_SPECIFIC: int
SI_ACCESS_GENERAL: int
SI_ACCESS_CONTAINER: int
SI_ACCESS_PROPERTY: int
SI_PAGE_PERM: int
SI_PAGE_ADVPERM: int
SI_PAGE_AUDIT: int
SI_PAGE_OWNER: int
SI_PAGE_EFFECTIVE: int
PSPCB_SI_INITDIALOG: int
ACTRL_DS_LIST: int
ACTRL_DS_LIST_OBJECT: int
CFSTR_ACLUI_SID_INFO_LIST: str
DS_LIST_ACCOUNT_OBJECT_FOR_SERVER: int
DS_LIST_DNS_HOST_NAME_FOR_SERVER: int
DS_LIST_DSA_OBJECT_FOR_SERVER: int
FILE_LIST_DIRECTORY: int



from _typeshed import Incomplete, ReadableBuffer
from collections.abc import Callable, Iterable
from typing import TypedDict
from typing_extensions import deprecated

import _win32typing
from win32.lib.pywintypes import TimeType, error as error

class _MonitorInfo(TypedDict):
    Monitor: tuple[int, int, int, int]
    Work: tuple[int, int, int, int]
    Flags: int
    Device: str

class _FileVersionInfo(TypedDict):
    Signature: int
    StrucVersion: int
    FileVersionMS: int
    FileVersionLS: int
    ProductVersionMS: int
    ProductVersionLS: int
    FileFlagsMask: int
    FileFlags: int
    FileOS: int
    FileType: int
    FileSubtype: int
    FileDate: None | Incomplete

def AbortSystemShutdown(computerName: str, /) -> None: ...
def InitiateSystemShutdown(computerName: str, message: str, timeOut, bForceClose, bRebootAfterShutdown, /) -> None: ...
def Apply(exceptionHandler, func, args, /): ...
def Beep(freq, dur, /) -> None: ...
def BeginUpdateResource(filename: str, delete, /) -> int: ...
def ChangeDisplaySettings(DevMode: _win32typing.PyDEVMODE, Flags, /): ...
def ChangeDisplaySettingsEx(DeviceName: str | None = ..., DevMode: _win32typing.PyDEVMODE | None = ..., Flags=...) -> int: ...
def ClipCursor(arg: tuple[Incomplete, Incomplete, Incomplete, Incomplete], /) -> None: ...
def CloseHandle(handle: int, /) -> None: ...
def CopyFile(src, dest: str, bFailOnExist: int = ..., /) -> None: ...
def DebugBreak() -> None: ...
def DeleteFile(fileName: str, /) -> None: ...
def DragQueryFile(hDrop, fileNum: int = ..., /) -> str: ...
def DragFinish(hDrop, /) -> None: ...
def DuplicateHandle(
    hSourceProcess: int, hSource: int, hTargetProcessHandle: int, desiredAccess: int, bInheritHandle: int, options: int, /
) -> int: ...
def EndUpdateResource(handle: int, discard, /) -> None: ...
def EnumDisplayDevices(Device: str | None = ..., DevNum: int = ..., Flags: int = ...) -> _win32typing.PyDISPLAY_DEVICE: ...
def EnumDisplayMonitors(
    hdc: int | None = ..., rcClip: _win32typing.PyRECT | None = ...
) -> list[tuple[_win32typing.PyHANDLE, _win32typing.PyHANDLE, tuple[int, int, int, int]]]: ...
def EnumDisplaySettings(DeviceName: str | None = ..., ModeNum: int = ...) -> _win32typing.PyDEVMODEW: ...
def EnumDisplaySettingsEx(DeviceName: str | None = ..., ModeNum=..., Flags=...) -> _win32typing.PyDEVMODEW: ...
def EnumResourceLanguages(
    hmodule: int, lpType: _win32typing.PyResourceId, lpName: _win32typing.PyResourceId, /
) -> list[Incomplete]: ...
def EnumResourceNames(hmodule: int, resType: _win32typing.PyResourceId, /) -> list[str]: ...
def EnumResourceTypes(hmodule: int, /) -> list[Incomplete]: ...
def ExpandEnvironmentStrings(_in: str, /) -> str: ...
def ExitWindows(reserved1: int = ..., reserved2: int = ..., /) -> None: ...
def ExitWindowsEx(flags, reserved: int = ..., /) -> None: ...
def FindFiles(fileSpec: str, /): ...
def FindFirstChangeNotification(pathName: str, bSubDirs, _filter, /): ...
def FindNextChangeNotification(handle: int, /) -> None: ...
def FindCloseChangeNotification(handle, /) -> None: ...
def FindExecutable(filename: str, _dir: str, /) -> tuple[Incomplete, str]: ...
def FormatMessage(
    flags: int, source: str | None = ..., messageId: int = ..., languageID: int = ..., inserts: Iterable[str] | None = ..., /
) -> str: ...
def FormatMessageW(
    flags: int, source: int | None = ..., messageId: int = ..., languageID: int = ..., inserts: Iterable[str] | None = ..., /
) -> str: ...
def FreeLibrary(hModule: int, /) -> None: ...
def GenerateConsoleCtrlEvent(controlEvent: int, processGroupId: int, /) -> None: ...
def GetAsyncKeyState(key, /): ...
def GetCommandLine() -> str: ...
def GetComputerName() -> str: ...
def GetComputerNameEx(NameType, /) -> str: ...
def GetComputerObjectName(NameFormat, /) -> str: ...
def GetMonitorInfo(hMonitor: int) -> _MonitorInfo: ...
def GetUserName() -> str: ...
def GetUserNameEx(NameFormat: int, /) -> str: ...
def GetCursorPos() -> tuple[Incomplete, Incomplete]: ...
def GetCurrentThread(): ...
def GetCurrentThreadId(): ...
def GetCurrentProcessId(): ...
def GetCurrentProcess() -> int: ...
def GetConsoleTitle() -> str: ...
def GetDateFormat(locale, flags, time: TimeType, _format: str, /) -> str: ...
def GetDiskFreeSpace(rootPath: str, /): ...
def GetDiskFreeSpaceEx(rootPath: str, /) -> tuple[int, int, int]: ...
def GetDllDirectory() -> str: ...
def GetDomainName() -> str: ...
def GetEnvironmentVariable(variable, /): ...
def GetEnvironmentVariableW(Name, /) -> str: ...
def GetFileAttributes(pathName: str, /): ...
def GetFileVersionInfo(Filename: str, SubBlock: str, /) -> _FileVersionInfo: ...
def GetFocus(): ...
def GetFullPathName(fileName: str, /) -> str: ...
def GetHandleInformation(Object: int, /): ...
def GetKeyboardLayout(threadId: int = ..., /): ...
def GetKeyboardLayoutName(): ...
def GetKeyboardState() -> str: ...
def GetKeyState(key, /): ...
def GetLastError(): ...
def GetLastInputInfo(): ...
def GetLocalTime(): ...
def GetLongPathName(fileName: str, /) -> str: ...
def GetLongPathNameW(fileName: str, /) -> str: ...
def GetLogicalDrives(): ...
def GetLogicalDriveStrings() -> str: ...
def GetModuleFileName(hModule: int, /) -> str: ...
def GetModuleFileNameW(hModule: int, /) -> str: ...
def GetModuleHandle(fileName: str | None = ..., /) -> int: ...
def GetPwrCapabilities(): ...
@deprecated("This function is obsolete, applications should use the registry instead.")
def GetProfileSection(section: str, iniName: str | None = ..., /): ...
def GetProcAddress(hModule: int, functionName: _win32typing.PyResourceId, /): ...
@deprecated("This function is obsolete, applications should use the registry instead.")
def GetProfileVal(section: str, entry: str, defValue: str, iniName: str | None = ..., /) -> str: ...
def GetShortPathName(path: str, /) -> str: ...
def GetStdHandle(handle: int, /) -> _win32typing.PyHANDLE: ...
def GetSysColor(index: int, /) -> int: ...
def GetSystemDefaultLangID(): ...
def GetSystemDefaultLCID(): ...
def GetSystemDirectory() -> str: ...
def GetSystemFileCacheSize(): ...
def SetSystemFileCacheSize(MinimumFileCacheSize, MaximumFileCacheSize, Flags=...) -> None: ...
def GetSystemInfo(): ...
def GetNativeSystemInfo(): ...
def GetSystemMetrics(index: int, /) -> int: ...
def GetSystemPowerStatus() -> dict[str, int]: ...
def GetSystemTime(): ...
def GetTempFileName(path: str, prefix: str, nUnique, /): ...
def GetTempPath() -> str: ...
def GetThreadLocale(): ...
def GetTickCount() -> int: ...
def GetTimeFormat(locale, flags, time: TimeType, _format: str, /) -> str: ...
def GetTimeZoneInformation(times_as_tuples: bool = ..., /): ...
def GetVersion(): ...
def GetVersionEx(_format: int = ..., /): ...
def GetVolumeInformation(path: str, /): ...
def GetWindowsDirectory() -> str: ...
def GetWindowLong(hwnd: int | None, offset: int, /) -> int: ...
def GetUserDefaultLangID(): ...
def GetUserDefaultLCID(): ...
def GlobalMemoryStatus(): ...
def GlobalMemoryStatusEx() -> dict[str, int]: ...
def keybd_event(bVk, bScan, dwFlags: int = ..., dwExtraInfo: int = ..., /) -> None: ...
def mouse_event(dx, dy, dwData, dwFlags: int = ..., dwExtraInfo=..., /) -> None: ...
def LoadCursor(hInstance: int, cursorid: _win32typing.PyResourceId, /) -> int: ...
def LoadKeyboardLayout(KLID: str, Flags: int = ..., /): ...
def LoadLibrary(fileName: str, /): ...
def LoadLibraryEx(fileName: str, handle: int, handle1, /) -> int: ...
def LoadResource(handle: int, _type: _win32typing.PyResourceId, name: _win32typing.PyResourceId, language, /) -> str: ...
def LoadString(handle: int, stringId, numChars: int = ..., /) -> str: ...
def MessageBeep(type: int, /): ...
def MessageBox(hwnd: int | None, message: str, title: str | None = ..., style=..., language=..., /) -> int: ...
def MonitorFromPoint(pt: tuple[Incomplete, Incomplete], Flags: int = ...) -> int: ...
def MonitorFromRect(rc: _win32typing.PyRECT | tuple[int, int, int, int], Flags: int = ...) -> int: ...
def MonitorFromWindow(hwnd: int, Flags: int = ...) -> int: ...
def MoveFile(srcName: str, destName: str, /) -> None: ...
def MoveFileEx(srcName: str, destName: str, flag, /) -> None: ...
def OpenProcess(reqdAccess: int, bInherit: int | bool, pid: int, /) -> int: ...
def OutputDebugString(msg: str, /) -> None: ...
def PostMessage(hwnd: int, idMessage, wParam: Incomplete | None = ..., lParam: Incomplete | None = ..., /) -> None: ...
def PostQuitMessage(exitCode: int = ..., /) -> None: ...
def PostThreadMessage(tid, idMessage, wParam: Incomplete | None = ..., lParam: Incomplete | None = ..., /) -> None: ...
def RegCloseKey(key: _win32typing.PyHKEY, /) -> None: ...
def RegConnectRegistry(computerName: str, key, /): ...
def RegCopyTree(KeySrc: _win32typing.PyHKEY, SubKey: str, KeyDest: _win32typing.PyHKEY) -> None: ...
def RegCreateKey(key: _win32typing.PyHKEY | int, subKey: str, /) -> _win32typing.PyHKEY: ...
def RegCreateKeyEx(
    Key: _win32typing.PyHKEY,
    SubKey: str,
    samDesired,
    Class: str | None = ...,
    Options=...,
    SecurityAttributes: _win32typing.PySECURITY_ATTRIBUTES | None = ...,
    Transaction: int | None = ...,
) -> tuple[_win32typing.PyHKEY, Incomplete]: ...
def RegDeleteKey(key: _win32typing.PyHKEY, subKey: str, /) -> None: ...
def RegDeleteKeyEx(Key: _win32typing.PyHKEY, SubKey: str, samDesired: int = ..., Transaction: int | None = ...) -> None: ...
def RegDeleteTree(Key: _win32typing.PyHKEY, SubKey: str) -> None: ...
def RegDeleteValue(key: _win32typing.PyHKEY, value: str, /) -> None: ...
def RegEnumKey(key: _win32typing.PyHKEY, index, /) -> str: ...
def RegEnumKeyEx(Key: _win32typing.PyHKEY, /): ...
def RegEnumKeyExW(Key: _win32typing.PyHKEY, /): ...
def RegEnumValue(key: _win32typing.PyHKEY, index, /) -> tuple[str, Incomplete, Incomplete]: ...
def RegFlushKey(key: _win32typing.PyHKEY, /) -> None: ...
def RegGetKeySecurity(key: _win32typing.PyHKEY, security_info, /) -> _win32typing.PySECURITY_DESCRIPTOR: ...
def RegLoadKey(key: _win32typing.PyHKEY, subKey: str, filename: str, /) -> None: ...
def RegOpenCurrentUser(samDesired=..., /) -> _win32typing.PyHKEY: ...
def RegOpenKey(
    key: _win32typing.PyHKEY | int, subkey: str | None, reserved: bool = ..., sam: int = ..., /
) -> _win32typing.PyHKEY: ...
def RegOpenKeyEx(key: _win32typing.PyHKEY, subKey: str, sam: int, reserved: bool = ..., /) -> _win32typing.PyHKEY: ...
def RegOpenKeyTransacted(
    Key: _win32typing.PyHKEY, SubKey: str, samDesired, Transaction: int, Options: int = ...
) -> _win32typing.PyHKEY: ...
def RegOverridePredefKey(Key: _win32typing.PyHKEY, NewKey: _win32typing.PyHKEY) -> None: ...
def RegQueryValue(key: _win32typing.PyHKEY | int, subKey: str | None, /) -> str: ...
def RegQueryValueEx(key: _win32typing.PyHKEY | int, valueName: str | None, /) -> tuple[str, int]: ...
def RegQueryInfoKey(key: _win32typing.PyHKEY, /) -> tuple[Incomplete, Incomplete, Incomplete]: ...
def RegQueryInfoKeyW(Key: _win32typing.PyHKEY, /): ...
def RegRestoreKey(Key: _win32typing.PyHKEY, File: str, Flags: int = ...) -> None: ...
def RegSaveKey(key: _win32typing.PyHKEY, filename: str, sa: _win32typing.PySECURITY_ATTRIBUTES | None = ..., /) -> None: ...
def RegSaveKeyEx(
    Key: _win32typing.PyHKEY, File: str, SecurityAttributes: _win32typing.PySECURITY_ATTRIBUTES | None = ..., Flags=...
) -> None: ...
def RegSetKeySecurity(key: _win32typing.PyHKEY, security_info, sd: _win32typing.PySECURITY_DESCRIPTOR, /) -> None: ...
def RegSetValue(key: _win32typing.PyHKEY, subKey: str | None, _type, value: str, /) -> None: ...
def RegSetValueEx(key: _win32typing.PyHKEY, valueName: str, reserved, _type, value, /) -> None: ...
def RegUnLoadKey(key: _win32typing.PyHKEY, subKey: str, /) -> None: ...
def RegisterWindowMessage(msgString: str, /) -> None: ...
def RegNotifyChangeKeyValue(key: _win32typing.PyHKEY, bWatchSubTree, dwNotifyFilter, hKey: int, fAsynchronous, /) -> None: ...
def SearchPath(path: str, fileName: str, fileExt: str | None = ..., /): ...
def SendMessage(hwnd: int, idMessage, wParam: str | None = ..., lParam: str | None = ..., /) -> None: ...
def SetConsoleCtrlHandler(ctrlHandler: Callable[[int], bool], bAdd: bool, /) -> None: ...
def SetConsoleTitle(title: str, /) -> None: ...
def SetCursorPos(arg: tuple[Incomplete, Incomplete], /) -> None: ...
def SetDllDirectory(PathName: str, /) -> None: ...
def SetErrorMode(errorMode, /): ...
def SetFileAttributes(pathName: str, attrs, /): ...
def SetLastError(): ...
def SetSysColors(Elements, RgbValues, /) -> None: ...
def SetLocalTime(SystemTime: TimeType, /) -> None: ...
def SetSystemTime(year, month, dayOfWeek, day, hour, minute, second, millseconds, /): ...
def SetClassLong(hwnd: int, offset, val, /): ...
@deprecated("This function is obsolete, use `win32api.SetClassLong` instead.")
def SetClassWord(hwnd: int, offset, val, /): ...
def SetCursor(hCursor: int, /) -> int: ...
def SetEnvironmentVariable(Name, Value, /) -> None: ...
def SetEnvironmentVariableW(Name, Value, /) -> None: ...
def SetHandleInformation(Object: int, Mask, Flags, /) -> None: ...
def SetStdHandle(handle, handle1: int, /) -> None: ...
def SetSystemPowerState(Suspend, Force, /) -> None: ...
def SetThreadLocale(lcid, /) -> None: ...
def SetTimeZoneInformation(tzi, /): ...
def SetWindowLong(hwnd: int | None, offset: int, value: float, /) -> int: ...
@deprecated("This function is obsolete, use `win32api.SetWindowLong` instead.")
def SetWindowWord(hwnd, offset: int, val: int) -> int: ...
def ShellExecute(hwnd: int, op: str, file: str, params: str, _dir: str, bShow, /): ...
def ShowCursor(show, /): ...
def Sleep(time, bAlterable: int = ..., /): ...
def TerminateProcess(handle: int, exitCode: int, /) -> None: ...
def ToAsciiEx(vk, scancode, keyboardstate, flags: int = ..., hlayout: Incomplete | None = ..., /): ...
def UpdateResource(
    handle: int,
    type: _win32typing.PyResourceId | int,
    name: _win32typing.PyResourceId | int,
    data: ReadableBuffer | None,
    language: int = ...,
    /,
) -> None: ...
def VkKeyScan(char: str | bytes, /): ...
def WinExec(cmdLine: str, arg, /) -> None: ...
def WinHelp(hwnd: int, hlpFile: str, cmd, data: str | int = ..., /) -> None: ...
@deprecated("This function is obsolete, applications should use the registry instead.")
def WriteProfileSection(section: str, data: str, iniName: str | None = ..., /): ...
@deprecated("This function is obsolete, applications should use the registry instead.")
def WriteProfileVal(section: str, entry: str, value: str, iniName: str | None = ..., /) -> None: ...
def HIBYTE(val: int, /) -> int: ...
def LOBYTE(val: int, /) -> int: ...
def HIWORD(val: int, /) -> int: ...
def LOWORD(val: int, /) -> int: ...
def RGB(red: int, green: int, blue: int, /) -> int: ...
def MAKELANGID(PrimaryLanguage, SubLanguage, /): ...
def MAKEWORD(low, high, /): ...
def MAKELONG(low, high, /): ...
def CommandLineToArgv(*args): ...  # incomplete
def GetKeyboardLayoutList(*args): ...  # incomplete
def MapVirtualKey(*args): ...  # incomplete
def MessageBoxEx(*args): ...  # incomplete
def OpenThread(*args): ...  # incomplete
def SleepEx(*args): ...  # incomplete
def VkKeyScanEx(*args): ...  # incomplete

NameCanonical: int
NameCanonicalEx: int
NameDisplay: int
NameFullyQualifiedDN: int
NameSamCompatible: int
NameServicePrincipal: int
NameUniqueId: int
NameUnknown: int
NameUserPrincipal: int
PyDISPLAY_DEVICEType = _win32typing.PyDISPLAY_DEVICE
REG_NOTIFY_CHANGE_ATTRIBUTES: int
REG_NOTIFY_CHANGE_LAST_SET: int
REG_NOTIFY_CHANGE_NAME: int
REG_NOTIFY_CHANGE_SECURITY: int
STD_ERROR_HANDLE: int
STD_INPUT_HANDLE: int
STD_OUTPUT_HANDLE: int
VFT_APP: int
VFT_DLL: int
VFT_DRV: int
VFT_FONT: int
VFT_STATIC_LIB: int
VFT_UNKNOWN: int
VFT_VXD: int
VOS_DOS: int
VOS_DOS_WINDOWS16: int
VOS_DOS_WINDOWS32: int
VOS_NT: int
VOS_NT_WINDOWS32: int
VOS_OS216: int
VOS_OS216_PM16: int
VOS_OS232: int
VOS_OS232_PM32: int
VOS_UNKNOWN: int
VOS__PM16: int
VOS__PM32: int
VOS__WINDOWS16: int
VOS__WINDOWS32: int
VS_FF_DEBUG: int
VS_FF_INFOINFERRED: int
VS_FF_PATCHED: int
VS_FF_PRERELEASE: int
VS_FF_PRIVATEBUILD: int
VS_FF_SPECIALBUILD: int



from typing import Any, Final

from win32.lib.pywintypes import error as error

def ChangeClipboardChain(hWndRemove: int, hWndNewNext: int, /): ...
def CloseClipboard(): ...
def CountClipboardFormats(): ...
def EmptyClipboard(): ...
def EnumClipboardFormats(_format: int = ..., /): ...
def GetClipboardData(_format, /) -> Any: ...  # str or bytes depending on the dib format
def GetClipboardDataHandle(_format, /): ...
def GetClipboardFormatName(_format, /) -> str: ...
def GetClipboardOwner(): ...
def GetClipboardSequenceNumber(): ...
def GetClipboardViewer(): ...
def GetGlobalMemory(hglobal: int, /) -> str: ...
def GetOpenClipboardWindow(): ...
def GetPriorityClipboardFormat(formats, /): ...
def IsClipboardFormatAvailable(format: int, /) -> int: ...
def OpenClipboard(hWnd: int | None = ..., /): ...
def RegisterClipboardFormat(name: str, /): ...
def SetClipboardData(_format, hMem, /): ...
def SetClipboardText(text, _format, /): ...
def SetClipboardViewer(hWndNewViewer: int, /) -> int: ...

CF_BITMAP: Final[int]
CF_DIB: Final[int]
CF_DIBV5: Final[int]
CF_DIF: Final[int]
CF_DSPBITMAP: Final[int]
CF_DSPENHMETAFILE: Final[int]
CF_DSPMETAFILEPICT: Final[int]
CF_DSPTEXT: Final[int]
CF_ENHMETAFILE: Final[int]
CF_HDROP: Final[int]
CF_LOCALE: Final[int]
CF_MAX: Final[int]
CF_METAFILEPICT: Final[int]
CF_OEMTEXT: Final[int]
CF_OWNERDISPLAY: Final[int]
CF_PALETTE: Final[int]
CF_PENDATA: Final[int]
CF_RIFF: Final[int]
CF_SYLK: Final[int]
CF_TEXT: Final[int]
CF_TIFF: Final[int]
CF_UNICODETEXT: Final[int]
CF_WAVE: Final[int]
UNICODE: bool



from _typeshed import Incomplete

import pythoncom

class COMException(pythoncom.com_error):
    scode: Incomplete
    description: Incomplete
    source: Incomplete
    helpfile: Incomplete
    helpcontext: Incomplete
    def __init__(
        self,
        description: Incomplete | None = ...,
        scode: Incomplete | None = ...,
        source: Incomplete | None = ...,
        helpfile: Incomplete | None = ...,
        helpContext: Incomplete | None = ...,
        desc: Incomplete | None = ...,
        hresult: Incomplete | None = ...,
    ) -> None: ...

def IsCOMException(t: Incomplete | None = ...): ...
def IsCOMServerException(t: Incomplete | None = ...): ...



from _typeshed import Incomplete

from win32comext.axdebug import gateways

def GetGoodFileName(fname): ...

class DebugDocumentProvider(gateways.DebugDocumentProvider):
    doc: Incomplete
    def __init__(self, doc) -> None: ...
    def GetName(self, dnt): ...
    def GetDocumentClassId(self): ...
    def GetDocument(self): ...

class DebugDocumentText(gateways.DebugDocumentText):
    codeContainer: Incomplete
    def __init__(self, codeContainer) -> None: ...
    def GetName(self, dnt): ...
    def GetDocumentClassId(self): ...
    def GetSize(self): ...
    def GetPositionOfLine(self, cLineNumber): ...
    def GetLineOfPosition(self, charPos): ...
    def GetText(self, charPos, maxChars, wantAttr): ...
    def GetPositionOfContext(self, context): ...
    def GetContextOfPosition(self, charPos, maxChars): ...

class CodeContainerProvider:
    ccsAndNodes: Incomplete
    def AddCodeContainer(self, cc, node: Incomplete | None = ...) -> None: ...
    def FromFileName(self, fname): ...
    def Close(self) -> None: ...



from _typeshed import Incomplete

class ISAPIError(Exception):
    errno: Incomplete
    strerror: Incomplete
    funcname: Incomplete
    def __init__(self, errno, strerror: Incomplete | None = None, funcname: Incomplete | None = None) -> None: ...

class FilterError(ISAPIError): ...
class ExtensionError(ISAPIError): ...
class InternalReloadException(Exception): ...



import bdb
from _typeshed import Incomplete

from win32comext.axdebug import gateways
from win32comext.axdebug.util import trace

def fnull(*args) -> None: ...

debugging: int
traceenter = fnull
tracev = fnull
traceenter = trace
tracev = trace

class OutputReflector:
    writefunc: Incomplete
    file: Incomplete
    def __init__(self, file, writefunc) -> None: ...
    def __getattr__(self, name: str): ...
    def write(self, message) -> None: ...

g_adb: Incomplete

def OnSetBreakPoint(codeContext, breakPointState, lineNo) -> None: ...

class Adb(bdb.Bdb, gateways.RemoteDebugApplicationEvents):
    debugApplication: Incomplete
    debuggingThread: Incomplete
    debuggingThreadStateHandle: Incomplete
    stackSnifferCookie: Incomplete
    codeContainerProvider: Incomplete
    breakFlags: Incomplete
    breakReason: Incomplete
    appDebugger: Incomplete
    appEventConnection: Incomplete
    logicalbotframe: Incomplete
    currentframe: Incomplete
    recursiveData: Incomplete
    def __init__(self) -> None: ...
    def canonic(self, fname): ...
    def reset(self) -> None: ...
    def stop_here(self, frame): ...
    def break_here(self, frame): ...
    def break_anywhere(self, frame): ...
    def dispatch_return(self, frame, arg): ...
    def dispatch_line(self, frame): ...
    def dispatch_call(self, frame, arg): ...
    def trace_dispatch(self, frame, event, arg): ...
    def user_line(self, frame) -> None: ...
    def user_return(self, frame, return_value) -> None: ...
    def user_exception(self, frame, exc_info) -> None: ...
    def set_trace(self) -> None: ...  # type: ignore[override]
    def CloseApp(self) -> None: ...
    stackSniffer: Incomplete
    def AttachApp(self, debugApplication, codeContainerProvider) -> None: ...
    def ResetAXDebugging(self) -> None: ...
    botframe: Incomplete
    stopframe: Incomplete
    def SetupAXDebugging(self, baseFrame: Incomplete | None = ..., userFrame: Incomplete | None = ...) -> None: ...
    def OnConnectDebugger(self, appDebugger): ...
    def OnDisconnectDebugger(self) -> None: ...
    def OnSetName(self, name) -> None: ...
    def OnDebugOutput(self, string) -> None: ...
    def OnClose(self) -> None: ...
    def OnEnterBreakPoint(self, rdat) -> None: ...
    def OnLeaveBreakPoint(self, rdat) -> None: ...
    def OnCreateThread(self, rdat) -> None: ...
    def OnDestroyThread(self, rdat) -> None: ...
    def OnBreakFlagChange(self, abf, rdat) -> None: ...

def Debugger(): ...



# The `winxpgui` module is obsolete and has been completely replaced
# by `win32gui` and `win32console.GetConsoleWindow`. Use those instead.

from win32console import GetConsoleWindow as GetConsoleWindow
from win32gui import *



from _typeshed import Incomplete

import _win32typing

def HexFromBin(val: str, /) -> str: ...
def BinFromHex(val: str, /) -> str: ...
def MAPIUninitialize() -> None: ...
def MAPIInitialize(init: _win32typing.MAPIINIT_0, /) -> None: ...
def MAPILogonEx(uiParam, profileName: str, password: str | None = ..., flags=..., /) -> _win32typing.PyIMAPISession: ...
def MAPIAdminProfiles(fFlags, /) -> _win32typing.PyIProfAdmin: ...
def HrQueryAllRows(
    table: _win32typing.PyIMAPITable,
    properties: _win32typing.PySPropTagArray,
    restrictions: _win32typing.PySRestriction,
    sortOrderSet: _win32typing.PySSortOrderSet,
    rowsMax,
    /,
): ...
def RTFSync(message: _win32typing.PyIMessage, flags, /): ...
def WrapCompressedRTFStream(stream: _win32typing.PyIStream, flags, /) -> _win32typing.PyIStream: ...
def WrapCompressedRTFStreamEx(stream: _win32typing.PyIStream, wcsinfo, /) -> tuple[_win32typing.PyIStream, Incomplete]: ...
def OpenIMsgSession(): ...
def CloseIMsgSession() -> None: ...
def OpenIMsgOnIStg(
    session,
    support,
    storage: _win32typing.PyIStorage,
    callback: Incomplete | None = ...,
    callbackData: int = ...,
    flags: int = ...,
    /,
) -> _win32typing.PyIMessage: ...
def RTFStreamToHTML(The_stream_to_read_the_uncompressed_RTF_from: _win32typing.PyIStream, /) -> None: ...
def OpenStreamOnFile(filename: str, flags: int = ..., prefix: str | None = ..., /) -> _win32typing.PyIStream: ...
def OpenStreamOnFileW(filename, flags: int = ..., prefix: Incomplete | None = ..., /) -> _win32typing.PyIStream: ...
def HrGetOneProp(prop: _win32typing.PyIMAPIProp, propTag, /): ...
def HrSetOneProp(prop: _win32typing.PyIMAPIProp, propValue: _win32typing.PySPropValue, /): ...
def HrAllocAdviseSink(callback, context, /): ...
def HrThisThreadAdviseSink(_object, /): ...
def HrDispatchNotifications(*args): ...  # incomplete
def MAPIUIDFromBinary(*args): ...  # incomplete

AB_NO_DIALOG: int
ATTACH_BY_REF_ONLY: int
ATTACH_BY_REF_RESOLVE: int
ATTACH_BY_REFERENCE: int
ATTACH_BY_VALUE: int
ATTACH_EMBEDDED_MSG: int
ATTACH_OLE: int
BMR_EQZ: int
BMR_NEZ: int
BOOKMARK_BEGINNING: int
BOOKMARK_CURRENT: int
BOOKMARK_END: int
CCSF_8BITHEADERS: int
CCSF_EMBEDDED_MESSAGE: int
CCSF_INCLUDE_BCC: int
CCSF_NO_MSGID: int
CCSF_NOHEADERS: int
CCSF_PLAIN_TEXT_ONLY: int
CCSF_PRESERVE_SOURCE: int
CCSF_SMTP: int
CCSF_USE_RTF: int
CCSF_USE_TNEF: int
CLEAR_NRN_PENDING: int
CLEAR_READ_FLAG: int
CLEAR_RN_PENDING: int
CONVENIENT_DEPTH: int
DEL_FOLDERS: int
DEL_MESSAGES: int
DELETE_HARD_DELETE: int
DIR_BACKWARD: int
FL_FULLSTRING: int
FL_IGNORECASE: int
FL_IGNORENONSPACE: int
FL_LOOSE: int
FL_PREFIX: int
FL_SUBSTRING: int
FLUSH_ASYNC_OK: int
FLUSH_DOWNLOAD: int
FLUSH_FORCE: int
FLUSH_NO_UI: int
FLUSH_UPLOAD: int
fnevCriticalError: int
fnevExtended: int
fnevNewMail: int
fnevObjectCopied: int
fnevObjectCreated: int
fnevObjectDeleted: int
fnevObjectModified: int
fnevObjectMoved: int
fnevReservedForMapi: int
fnevSearchComplete: int
fnevStatusObjectModified: int
fnevTableModified: int
FOLDER_DIALOG: int
FOLDER_GENERIC: int
FOLDER_SEARCH: int
FORCE_SAVE: int
GENERATE_RECEIPT_ONLY: int
KEEP_OPEN_READONLY: int
KEEP_OPEN_READWRITE: int
LOGOFF_ABORT: int
LOGOFF_COMPLETE: int
LOGOFF_INBOUND: int
LOGOFF_NO_WAIT: int
LOGOFF_ORDERLY: int
LOGOFF_OUTBOUND: int
LOGOFF_OUTBOUND_QUEUE: int
LOGOFF_PURGE: int
LOGOFF_QUIET: int
MAIL_E_NAMENOTFOUND: int
MAPI_ABCONT: int
MAPI_ADDRBOOK: int
MAPI_ALLOW_OTHERS: int
MAPI_ASSOCIATED: int
MAPI_ATTACH: int
MAPI_BCC: int
MAPI_BEST_ACCESS: int
MAPI_CC: int
MAPI_CREATE: int
MAPI_DEFAULT_SERVICES: int
MAPI_DEFERRED_ERRORS: int
MAPI_DIALOG: int
MAPI_E_ACCOUNT_DISABLED: int
MAPI_E_AMBIGUOUS_RECIP: int
MAPI_E_BAD_CHARWIDTH: int
MAPI_E_BAD_COLUMN: int
MAPI_E_BAD_VALUE: int
MAPI_E_BUSY: int
MAPI_E_CALL_FAILED: int
MAPI_E_CANCEL: int
MAPI_E_COLLISION: int
MAPI_E_COMPUTED: int
MAPI_E_CORRUPT_DATA: int
MAPI_E_CORRUPT_STORE: int
MAPI_E_DECLINE_COPY: int
MAPI_E_DISK_ERROR: int
MAPI_E_END_OF_SESSION: int
MAPI_E_EXTENDED_ERROR: int
MAPI_E_FAILONEPROVIDER: int
MAPI_E_FOLDER_CYCLE: int
MAPI_E_HAS_FOLDERS: int
MAPI_E_HAS_MESSAGES: int
MAPI_E_INTERFACE_NOT_SUPPORTED: int
MAPI_E_INVALID_ACCESS_TIME: int
MAPI_E_INVALID_BOOKMARK: int
MAPI_E_INVALID_ENTRYID: int
MAPI_E_INVALID_OBJECT: int
MAPI_E_INVALID_PARAMETER: int
MAPI_E_INVALID_TYPE: int
MAPI_E_INVALID_WORKSTATION_ACCOUNT: int
MAPI_E_LOCKID_LIMIT: int
MAPI_E_LOGON_FAILED: int
MAPI_E_MISSING_REQUIRED_COLUMN: int
MAPI_E_NAMED_PROP_QUOTA_EXCEEDED: int
MAPI_E_NETWORK_ERROR: int
MAPI_E_NO_ACCESS: int
MAPI_E_NO_RECIPIENTS: int
MAPI_E_NO_SUPPORT: int
MAPI_E_NO_SUPPRESS: int
MAPI_E_NON_STANDARD: int
MAPI_E_NOT_ENOUGH_DISK: int
MAPI_E_NOT_ENOUGH_MEMORY: int
MAPI_E_NOT_ENOUGH_RESOURCES: int
MAPI_E_NOT_FOUND: int
MAPI_E_NOT_IN_QUEUE: int
MAPI_E_NOT_INITIALIZED: int
MAPI_E_NOT_ME: int
MAPI_E_OBJECT_CHANGED: int
MAPI_E_OBJECT_DELETED: int
MAPI_E_OFFLINE: int
MAPI_E_PASSWORD_CHANGE_REQUIRED: int
MAPI_E_PASSWORD_EXPIRED: int
MAPI_E_PROFILE_DELETED: int
MAPI_E_RECONNECTED: int
MAPI_E_SESSION_LIMIT: int
MAPI_E_STORE_FULL: int
MAPI_E_STRING_TOO_LONG: int
MAPI_E_SUBMITTED: int
MAPI_E_TABLE_EMPTY: int
MAPI_E_TABLE_TOO_BIG: int
MAPI_E_TIMEOUT: int
MAPI_E_TOO_BIG: int
MAPI_E_TOO_COMPLEX: int
MAPI_E_TYPE_NO_SUPPORT: int
MAPI_E_UNABLE_TO_ABORT: int
MAPI_E_UNABLE_TO_COMPLETE: int
MAPI_E_UNCONFIGURED: int
MAPI_E_UNEXPECTED_ID: int
MAPI_E_UNEXPECTED_TYPE: int
MAPI_E_UNKNOWN_CPID: int
MAPI_E_UNKNOWN_ENTRYID: int
MAPI_E_UNKNOWN_FLAGS: int
MAPI_E_UNKNOWN_LCID: int
MAPI_E_USER_CANCEL: int
MAPI_E_VERSION: int
MAPI_E_WAIT: int
MAPI_EXPLICIT_PROFILE: int
MAPI_EXTENDED: int
MAPI_FOLDER: int
MAPI_FORCE_ACCESS: int
MAPI_FORCE_DOWNLOAD: int
MAPI_FORMINFO: int
MAPI_INIT_VERSION: int
MAPI_LOGON_UI: int
MAPI_MAILUSER: int
MAPI_MESSAGE: int
MAPI_MODIFY: int
MAPI_MOVE: int
MAPI_MULTITHREAD_NOTIFICATIONS: int
MAPI_NATIVE_BODY: int
MAPI_NATIVE_BODY_TYPE_HTML: int
MAPI_NATIVE_BODY_TYPE_PLAINTEXT: int
MAPI_NATIVE_BODY_TYPE_RTF: int
MAPI_NEW_SESSION: int
MAPI_NO_IDS: int
MAPI_NO_MAIL: int
MAPI_NO_STRINGS: int
MAPI_NOREPLACE: int
MAPI_NT_SERVICE: int
MAPI_P1: int
MAPI_PASSWORD_UI: int
MAPI_PROFSECT: int
MAPI_SERVICE_UI_ALWAYS: int
MAPI_SESSION: int
MAPI_STATUS: int
MAPI_STORE: int
MAPI_SUBMITTED: int
MAPI_TIMEOUT_SHORT: int
MAPI_TO: int
MAPI_UNICODE: int
MAPI_USE_DEFAULT: int
MAPI_W_APPROX_COUNT: int
MAPI_W_CANCEL_MESSAGE: int
MAPI_W_ERRORS_RETURNED: int
MAPI_W_NO_SERVICE: int
MAPI_W_PARTIAL_COMPLETION: int
MAPI_W_POSITION_CHANGED: int
MDB_NO_DIALOG: int
MDB_NO_MAIL: int
MDB_TEMPORARY: int
MDB_WRITE: int
MESSAGE_DIALOG: int
MODRECIP_ADD: int
MODRECIP_MODIFY: int
MODRECIP_REMOVE: int
NO_ATTACHMENT: int
OPEN_IF_EXISTS: int
PSTF_BEST_ENCRYPTION: int
PSTF_COMPRESSABLE_ENCRYPTION: int
PSTF_NO_ENCRYPTION: int
RELOP_EQ: int
RELOP_GE: int
RELOP_GT: int
RELOP_LE: int
RELOP_LT: int
RELOP_NE: int
RELOP_RE: int
RES_AND: int
RES_BITMASK: int
RES_COMMENT: int
RES_COMPAREPROPS: int
RES_CONTENT: int
RES_EXIST: int
RES_NOT: int
RES_OR: int
RES_PROPERTY: int
RES_SIZE: int
RES_SUBRESTRICTION: int
RTF_SYNC_BODY_CHANGED: int
RTF_SYNC_RTF_CHANGED: int
SERVICE_UI_ALLOWED: int
SERVICE_UI_ALWAYS: int
SHOW_SOFT_DELETES: int
SOF_UNIQUEFILENAME: int
STATUS_DEFAULT_STORE: int
STATUS_FLUSH_QUEUES: int
STATUS_INBOUND_FLUSH: int
STATUS_OUTBOUND_FLUSH: int
SUPPRESS_RECEIPT: int
TABLE_CHANGED: int
TABLE_ERROR: int
TABLE_RELOAD: int
TABLE_RESTRICT_DONE: int
TABLE_ROW_ADDED: int
TABLE_ROW_DELETED: int
TABLE_ROW_MODIFIED: int
TABLE_SETCOL_DONE: int
TABLE_SORT_ASCEND: int
TABLE_SORT_COMBINE: int
TABLE_SORT_DESCEND: int
TABLE_SORT_DONE: int
TBL_ALL_COLUMNS: int
TBL_ASYNC: int
TBL_BATCH: int
CLSID_IConverterSession: _win32typing.PyIID
CLSID_MailMessage: _win32typing.PyIID
IID_IABContainer: _win32typing.PyIID
IID_IAddrBook: _win32typing.PyIID
IID_IAttachment: _win32typing.PyIID
IID_IConverterSession: _win32typing.PyIID
IID_IDistList: _win32typing.PyIID
IID_IMAPIAdviseSink: _win32typing.PyIID
IID_IMAPIContainer: _win32typing.PyIID
IID_IMAPIFolder: _win32typing.PyIID
IID_IMAPIProp: _win32typing.PyIID
IID_IMAPISession: _win32typing.PyIID
IID_IMAPIStatus: _win32typing.PyIID
IID_IMAPITable: _win32typing.PyIID
IID_IMailUser: _win32typing.PyIID
IID_IMessage: _win32typing.PyIID
IID_IMsgServiceAdmin: _win32typing.PyIID
IID_IMsgServiceAdmin2: _win32typing.PyIID
IID_IMsgStore: _win32typing.PyIID
IID_IProfAdmin: _win32typing.PyIID
IID_IProfSect: _win32typing.PyIID
IID_IProviderAdmin: _win32typing.PyIID
MAPI_DISTLIST: int
MSPST_UID_PROVIDER: _win32typing.PyIID
PSETID_Address: _win32typing.PyIID
PSETID_AirSync: _win32typing.PyIID
PSETID_Appointment: _win32typing.PyIID
PSETID_Common: _win32typing.PyIID
PSETID_Log: _win32typing.PyIID
PSETID_Meeting: _win32typing.PyIID
PSETID_Messaging: _win32typing.PyIID
PSETID_Note: _win32typing.PyIID
PSETID_PostRss: _win32typing.PyIID
PSETID_Remote: _win32typing.PyIID
PSETID_Report: _win32typing.PyIID
PSETID_Sharing: _win32typing.PyIID
PSETID_Task: _win32typing.PyIID
PSETID_UnifiedMessaging: _win32typing.PyIID
PS_INTERNET_HEADERS: _win32typing.PyIID
PS_MAPI: _win32typing.PyIID
PS_PUBLIC_STRINGS: _win32typing.PyIID
PS_ROUTING_ADDRTYPE: _win32typing.PyIID
PS_ROUTING_DISPLAY_NAME: _win32typing.PyIID
PS_ROUTING_EMAIL_ADDRESSES: _win32typing.PyIID
PS_ROUTING_ENTRYID: _win32typing.PyIID
PS_ROUTING_SEARCH_KEY: _win32typing.PyIID



import datetime
from _typeshed import Incomplete

log: Incomplete

class _SimpleStruct:
    def __init__(self, *args, **kw) -> None: ...
    def field_names(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...

class SYSTEMTIME(_SimpleStruct): ...
class TIME_ZONE_INFORMATION(_SimpleStruct): ...
class DYNAMIC_TIME_ZONE_INFORMATION(_SimpleStruct): ...

class TimeZoneDefinition(DYNAMIC_TIME_ZONE_INFORMATION):
    def __init__(self, *args, **kwargs) -> None: ...
    def __getattribute__(self, attr: str): ...
    @classmethod
    def current(cls): ...
    def set(self) -> None: ...
    def copy(self): ...
    def locate_daylight_start(self, year): ...
    def locate_standard_start(self, year): ...

class TimeZoneInfo(datetime.tzinfo):
    tzRegKey: str
    timeZoneName: Incomplete
    fixedStandardTime: Incomplete
    def __init__(self, param: Incomplete | None = ..., fix_standard_time: bool = ...) -> None: ...
    def tzname(self, dt): ...
    def getWinInfo(self, targetYear): ...
    def utcoffset(self, dt): ...
    def dst(self, dt): ...
    def GetDSTStartTime(self, year): ...
    def GetDSTEndTime(self, year): ...
    def __le__(self, other) -> bool: ...
    def __eq__(self, other) -> bool: ...
    def __ne__(self, other) -> bool: ...
    @classmethod
    def local(cls): ...
    @classmethod
    def utc(cls): ...
    @staticmethod
    def get_sorted_time_zone_names(): ...
    @staticmethod
    def get_all_time_zones(): ...
    @staticmethod
    def get_sorted_time_zones(key: Incomplete | None = ...): ...

def utcnow(): ...
def now(): ...
def GetTZCapabilities(): ...

class DLLHandleCache:
    def __getitem__(self, filename): ...

DLLCache: Incomplete

def resolveMUITimeZone(spec): ...

class RangeMap(dict[int, str]):
    sort_params: Incomplete
    match: Incomplete
    def __init__(self, source, sort_params=..., key_match_comparator=...) -> None: ...
    def __getitem__(self, item): ...
    def get(self, key, default: Incomplete | None = ...): ...
    def bounds(self): ...
    undefined_value: Incomplete

    class Item(int): ...
    first_item: Incomplete
    last_item: Incomplete
